@@ -72,7 +72,7 @@ class CloudStackProvider(object):
                 response = api.destroyVirtualMachine('GET',request)
             
                 try:
-                    if response['jobid']:
+                    if 'jobid' in response:
                         LOG.warning("VirtualMachine destroyed!")
 
                         #removing data from flipper
@@ -95,8 +95,8 @@ class CloudStackProvider(object):
                         paramiko.HostKeys().clear()
                         LOG.info("Removing key from known hosts!")
                         LOG.info("Finished!")
-                except (KeyError, LookupError):
-                    LOG.warning("We could not destroy the VirtualMachine. :(")
+                except Exception, e:
+                    LOG.warning("We could not destroy the VirtualMachine.  %s :(" % e)
         else:
             LOG.warning("Putting database %s in quarantine" % database.name)
             database.is_in_quarantine=True
@@ -189,8 +189,6 @@ class CloudStackProvider(object):
         project_id = self.get_credentials(environment= environment).project
         names = self.gen_infra_name(name, 2)
         infraname = names["infra"]
-        vmname = names["vms"][0]
-        
         
         #response = api.listVirtualMachines('GET',request)
         #print response
@@ -208,11 +206,34 @@ class CloudStackProvider(object):
         databaseinfra.save()
         LOG.info("DatabaseInfra created!")
 
-        instance1 = self.create_vm(api, planattr, project_id, infraname, names["vms"][0], plan, environment, True, databaseinfra)
-        instance2 = self.create_vm(api, planattr, project_id, infraname, names["vms"][1], plan, environment, True, databaseinfra)        
-        if instance1 is None or instance2 is None:
+        instances = []
+        x = 0 
+
+        for vmname in names["vms"]:
+            instances.append(self.create_vm(api, planattr, project_id, infraname, vmname, plan, environment, True, databaseinfra))
+
+            if x == 0 and instances[0]==None:
+                return None
+
+            if x ==1 and instances[1]==None:
+                LOG.warning("Destroying cloudstack cluster instance!")
+            
+                project_id = self.get_credentials(environment= environment).project
+
+                api = self.auth(environment= environment)
+                request = { 'projectid': '%s' % (project_id),
+                            'id': '%s' % (instances[0].hostname.cs_host_attributes.all()[0].vm_id)
+                          }
+                api.destroyVirtualMachine('GET',request)
+                return None
+
+            x+=1
+
+     
+        if None in instances:
             databaseinfra.delete()
             return None
+
         databasesinfraattr = DatabaseInfraAttr.objects.filter(databaseinfra=databaseinfra)
         databasesinfraattr[0].is_write = True
         databasesinfraattr[0].save()
@@ -226,8 +247,8 @@ class CloudStackProvider(object):
             'DBPASSWORD': 'root',
             'IPMASTER': None,
             'IPWRITE': writeip,
-            'HOST01': instance1.hostname,
-            'HOST02': instance2.hostname,
+            'HOST01': instances[0].hostname,
+            'HOST02': instances[1].hostname,
             'MASTERPAIRNAME': masterpairname,
             'SECOND_SCRIPT_FILE': second_script,
         }
@@ -262,26 +283,26 @@ class CloudStackProvider(object):
         flipper.create_flipper_dependencies(masterpairname= masterpairname, 
                                                                 readip= readip, 
                                                                 writeip= writeip, 
-                                                                instance1= instance1, 
-                                                                instance2= instance2, 
+                                                                instance1= instances[0], 
+                                                                instance2= instances[1], 
                                                                 environment= environment)
 
         
-        run_scripts_vms(contextdict, instance1.hostname, 1, instance2.address )
-        run_scripts_vms(contextdict, instance2.hostname, 2, instance1.address )
-        self.run_script(instance1.hostname, second_script)
-        self.run_script(instance2.hostname, second_script)
+        run_scripts_vms(contextdict, instances[0].hostname, 1, instances[1].address )
+        run_scripts_vms(contextdict, instances[1].hostname, 2, instances[0].address )
+        self.run_script(instances[0].hostname, second_script)
+        self.run_script(instances[1].hostname, second_script)
         
 
         #databaseinfra.endpoint = writeip + ":%i" %(3306)
-        databaseinfra.endpoint = instance1.hostname.hostname + ":%i" %(3306)
+        databaseinfra.endpoint = instances[0].hostname.hostname + ":%i" %(3306)
         databaseinfra.save()
         
-        instance1.databaseinfra = databaseinfra
-        instance1.save()
+        instances[0].databaseinfra = databaseinfra
+        instances[0].save()
 
-        instance2.databaseinfra = databaseinfra
-        instance2.save()
+        instances[1].databaseinfra = databaseinfra
+        instances[1].save()
 
         LOG.info("Instance created!")
         
